@@ -15,8 +15,11 @@
 
 // Konsole
 #include "Enumeration.h"
+#include "terminalDisplay/TerminalDisplay.h"
 #include "konsoleprivate_export.h"
 
+#include <memory>
+
 class QKeyEvent;
 
 namespace Konsole {
@@ -91,6 +94,11 @@ public:
      */
     ScreenWindow *createWindow();
 
+    /**
+     * Associates a TerminalDisplay with this emulation.
+     */
+    void setCurrentTerminalDisplay(TerminalDisplay *display);
+
     /** Returns the size of the screen image which the emulation produces */
     QSize imageSize() const;
 
@@ -440,7 +448,7 @@ protected:
     //decodes an incoming C-style character stream into a unicode QString using
     //the current text codec.  (this allows for rendering of non-ASCII characters in text files etc.)
     const QTextCodec *_codec;
-    QTextDecoder *_decoder;
+    std::unique_ptr<QTextDecoder> _decoder;
     const KeyboardTranslator *_keyTranslator; // the keyboard layout
 
 protected Q_SLOTS:
