@@ -494,6 +494,15 @@ void ViewManager::sessionFinished()
         return;
     }
 
+    if (_navigationMethod == TabbedNavigation) {
+        // The last session/tab, and only one view (no splits), emit empty()
+        // so that close() is called in MainWindow, fixes #432077
+        if (_viewContainer->count() == 1 && _viewContainer->currentTabViewCount() == 1) {
+            Q_EMIT empty();
+            return;
+        }
+    }
+
     auto *session = qobject_cast<Session *>(sender());
     Q_ASSERT(session);
 
