@@ -35,6 +35,41 @@ void ScreenTest::testLargeScreenCopyShortLine()
   doLargeScreenCopyVerification(putToScreen, expectedSelection);
 }
 
+void ScreenTest::testBlockSelection()
+{
+    Screen screen(largeScreenLines, largeScreenColumns);
+
+    const QString reallyBigTextForReflow = QStringLiteral(
+        "abcd efgh ijkl mnop qrst uvxz ABCD EFGH IJKL MNOP QRST UVXZ"
+    );
+
+    for(const auto c : reallyBigTextForReflow) {
+        screen.displayCharacter(c.toLatin1());
+    }
+
+
+    // this breaks the lines in `abcd efgh `
+    // reflowing everything to the lines below.
+    screen.setReflowLines(true);
+
+    // reflow does not reflows cursor line, so let's move it a bit down.
+    screen.cursorDown(1);
+    screen.resizeImage(largeScreenLines, 10);
+
+    // True here means block selection.
+    screen.setSelectionStart(0, 0, true);
+    screen.setSelectionEnd(3, 1);
+
+    // after the resize, the string should be:
+    // abcd efgh
+    // ijkl mnop
+    // ...
+    // I'm selecting the first two lines of the first column of strings,
+    // so, abcd ijkl.
+    const QString selectedText = screen.selectedText(Screen::PlainText);
+    QCOMPARE(screen.selectedText(Screen::PlainText), QStringLiteral("abcd ijkl"));
+}
+
 void ScreenTest::testLargeScreenCopyEmptyLine()
 {
   const QString putToScreen;
