@@ -18,6 +18,8 @@
 #include <QMouseEvent>
 #include <QKeyEvent>
 #include <QRegularExpression>
+#include <QDrag>
+#include <QMimeData>
 
 #include <KIO/ApplicationLauncherJob>
 #include <KIO/OpenUrlJob>
@@ -300,8 +302,24 @@ void FileFilterHotSpot::mouseLeaveEvent(TerminalDisplay *td, QMouseEvent *ev)
     stopThumbnailGeneration();
 }
 
-void Konsole::FileFilterHotSpot::keyPressEvent(Konsole::TerminalDisplay* td, QKeyEvent* ev)
+void FileFilterHotSpot::keyPressEvent(Konsole::TerminalDisplay* td, QKeyEvent* ev)
 {
     HotSpot::keyPressEvent(td, ev);
     requestThumbnail(ev->modifiers(), QCursor::pos());
 }
+
+
+bool FileFilterHotSpot::hasDragOperation() const
+{
+    return true;
+}
+
+void FileFilterHotSpot::startDrag()
+{
+    auto *drag = new QDrag(this);
+    auto *mimeData = new QMimeData();
+    mimeData->setUrls({QUrl::fromLocalFile(_filePath)});
+
+    drag->setMimeData(mimeData);
+    drag->exec(Qt::CopyAction);
+}
