@@ -20,32 +20,37 @@ HistoryScrollNone::HistoryScrollNone() :
 
 HistoryScrollNone::~HistoryScrollNone() = default;
 
-bool HistoryScrollNone::hasScroll()
+bool HistoryScrollNone::hasScroll() const
 {
     return false;
 }
 
-int HistoryScrollNone::getLines()
+int HistoryScrollNone::getLines() const
 {
     return 0;
 }
 
-int HistoryScrollNone::getMaxLines()
+int HistoryScrollNone::getMaxLines() const
 {
     return 0;
 }
 
-int HistoryScrollNone::getLineLen(int)
+int HistoryScrollNone::getLineLen(int) const
 {
     return 0;
 }
 
-bool HistoryScrollNone::isWrappedLine(int /*lineno*/)
+bool HistoryScrollNone::isWrappedLine(int /*lineno*/) const
 {
     return false;
 }
 
-void HistoryScrollNone::getCells(int, int, int, Character [])
+LineProperty HistoryScrollNone::getLineProperty(int /*lineno*/) const
+{
+    return 0;
+}
+
+void HistoryScrollNone::getCells(int, int, int, Character []) const
 {
 }
 
@@ -53,27 +58,11 @@ void HistoryScrollNone::addCells(const Character [], int)
 {
 }
 
-void HistoryScrollNone::addLine(bool)
+void HistoryScrollNone::addLine(LineProperty)
 {
 }
 
-void HistoryScrollNone::insertCells(int , const Character [], int)
-{
-}
-
-void HistoryScrollNone::removeCells(int )
-{
-}
-
-void HistoryScrollNone::insertCellsVector(int , const QVector<Character> &)
-{
-}
-
-void HistoryScrollNone::setCellsAt(int , const Character [], int)
-{
-}
-
-void HistoryScrollNone::setCellsVectorAt(int , const QVector<Character> &)
+void HistoryScrollNone::removeCells()
 {
 }
 
@@ -81,7 +70,3 @@ int HistoryScrollNone::reflowLines(int)
 {
     return 0;
 }
-
-void HistoryScrollNone::setLineAt(int , bool)
-{
-}
