@@ -77,17 +77,16 @@ EditProfileDialog::EditProfileDialog(QWidget *parent)
     _buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel | QDialogButtonBox::Apply);
     setButtonBox(_buttonBox);
 
-    QPushButton *okButton = _buttonBox->button(QDialogButtonBox::Ok);
-    okButton->setDefault(true);
-    connect(_buttonBox, &QDialogButtonBox::accepted, this, &Konsole::EditProfileDialog::accept);
-    connect(_buttonBox, &QDialogButtonBox::rejected, this, &Konsole::EditProfileDialog::reject);
+    _buttonBox->button(QDialogButtonBox::Ok)->setDefault(true);
 
-    // disable the apply button , since no modification has been made
-    _buttonBox->button(QDialogButtonBox::Apply)->setEnabled(false);
-
-    connect(_buttonBox->button(QDialogButtonBox::Apply),
-            &QPushButton::clicked, this,
-            &Konsole::EditProfileDialog::apply);
+    auto *applyButton = _buttonBox->button(QDialogButtonBox::Apply);
+    // Disable it, since no modifications have been made yet
+    applyButton->setEnabled(false);
+    connect(applyButton, &QPushButton::clicked, this, [this]() {
+        if (isProfileNameValid()) {
+            save();
+        }
+    });
 
     connect(_delayedPreviewTimer, &QTimer::timeout, this,
             &Konsole::EditProfileDialog::delayedPreviewActivate);
@@ -106,10 +105,10 @@ EditProfileDialog::EditProfileDialog(QWidget *parent)
     auto *generalPageWidget = new QWidget(this);
     _generalUi = new Ui::EditProfileGeneralPage();
     _generalUi->setupUi(generalPageWidget);
-    auto *generalPageItem = addPage(generalPageWidget, generalPageName);
-    generalPageItem->setHeader(generalPageName);
-    generalPageItem->setIcon(QIcon::fromTheme(QStringLiteral("utilities-terminal")));
-    _pages[generalPageItem] = Page(&EditProfileDialog::setupGeneralPage);
+    _generalPageItem = addPage(generalPageWidget, generalPageName);
+    _generalPageItem->setHeader(generalPageName);
+    _generalPageItem->setIcon(QIcon::fromTheme(QStringLiteral("utilities-terminal")));
+    _pages[_generalPageItem] = Page(&EditProfileDialog::setupGeneralPage);
 
     // Tabs page
 
@@ -259,44 +258,37 @@ void EditProfileDialog::reject()
 
 void EditProfileDialog::accept()
 {
-    // if the Apply button is disabled then no settings were changed
-    // or the changes have already been saved by apply()
-    if (_buttonBox->button(QDialogButtonBox::Apply)->isEnabled()) {
-        if (!isValidProfileName()) {
-            return;
-        }
+    if (isProfileNameValid()) {
         save();
+        unpreviewAll();
+        QDialog::accept();
     }
-
-    unpreviewAll();
-    QDialog::accept();
 }
 
-void EditProfileDialog::apply()
+void EditProfileDialog::setMessageGeneralPage(const QString &msg)
 {
-    if (!isValidProfileName()) {
-        return;
-    }
-    save();
+    _generalUi->generalPageMessageWidget->setText(msg);
+    _generalUi->generalPageMessageWidget->setMessageType(KMessageWidget::Error);
+    setCurrentPage(_generalPageItem);
+    _generalUi->generalPageMessageWidget->animatedShow();
 }
 
-bool EditProfileDialog::isValidProfileName()
+bool EditProfileDialog::isProfileNameValid()
 {
     Q_ASSERT(_profile);
     Q_ASSERT(_tempProfile);
 
     // check whether the user has enough permissions to save the profile
     QFileInfo fileInfo(_profile->path());
-    if (fileInfo.exists() && !fileInfo.isWritable()) {
-        if (!_tempProfile->isPropertySet(Profile::Name)
-            || (_tempProfile->name() == _profile->name())) {
-                KMessageBox::sorry(this,
-                                   i18n("<p>Konsole does not have permission to save this profile to:<br /> \"%1\"</p>"
-                                        "<p>To be able to save settings you can either change the permissions "
-                                        "of the profile configuration file or change the profile name to save "
-                                        "the settings to a new profile.</p>", _profile->path()));
-                return false;
-        }
+    if (fileInfo.exists() && !fileInfo.isWritable()
+        && (!_tempProfile->isPropertySet(Profile::Name) || _tempProfile->name() == _profile->name())) {
+        setMessageGeneralPage(
+            xi18nc("@info",
+                   "Insufficient permissions to save settings to: <filename>%1</filename>.<nl/>"
+                   "Either change the permissions of that file or set a different name to save "
+                   "the settings to a new profile.",
+                   _profile->path()));
+        return false;
     }
 
     const QList<Profile::Ptr> existingProfiles = ProfileManager::instance()->allProfiles();
@@ -308,26 +300,28 @@ bool EditProfileDialog::isValidProfileName()
         }
     }
 
-    if ((_tempProfile->isPropertySet(Profile::Name)
-         && _tempProfile->name().isEmpty())
+    if ((_tempProfile->isPropertySet(Profile::Name) && _tempProfile->name().isEmpty())
         || (_profile->name().isEmpty() && _tempProfile->name().isEmpty())) {
-        KMessageBox::sorry(this,
-                           i18n("<p>Each profile must have a name before it can be saved "
-                                "into disk.</p>"));
-        // revert the name in the dialog
+        setMessageGeneralPage(i18nc("@info",
+                                    "Profile Name was empty; please set a name to be able to save settings."));
+        // Revert the name in the dialog
         _generalUi->profileNameEdit->setText(_profile->name());
         selectProfileName();
         return false;
-    } else if (!_tempProfile->name().isEmpty() && otherExistingProfileNames.contains(_tempProfile->name())) {
-        KMessageBox::sorry(this,
-                            i18n("<p>A profile with this name already exists.</p>"));
-        // revert the name in the dialog
-        _generalUi->profileNameEdit->setText(_profile->name());
-        selectProfileName();
-        return false;
-    } else {
-        return true;
     }
+
+    if (!_tempProfile->name().isEmpty() && otherExistingProfileNames.contains(_tempProfile->name())) {
+        setMessageGeneralPage(i18nc("@info",
+                                    "A profile with the name \"%1\" already exists.",
+                                    _generalUi->profileNameEdit->text()));
+        // Revert the name in the dialog
+        _generalUi->profileNameEdit->setText(_profile->name());
+        selectProfileName();
+        return false;
+    }
+
+    // Valid name
+    return true;
 }
 
 QString EditProfileDialog::groupProfileNames(const ProfileGroup::Ptr &group, int maxLength)
@@ -348,7 +342,7 @@ QString EditProfileDialog::groupProfileNames(const ProfileGroup::Ptr &group, int
     return caption;
 }
 
-void EditProfileDialog::updateCaption(const Profile::Ptr &profile)
+void EditProfileDialog::updateCaption(const Profile::Ptr &profile, EditProfileDialog::InitialProfileState state)
 {
     const int MAX_GROUP_CAPTION_LENGTH = 25;
     ProfileGroup::Ptr group = profile->asGroup();
@@ -359,18 +353,22 @@ void EditProfileDialog::updateCaption(const Profile::Ptr &profile)
                              group->profiles().count(),
                              caption));
     } else {
-        setWindowTitle(i18n("Edit Profile \"%1\"", profile->name()));
+        if (state == EditProfileDialog::NewProfile) {
+            setWindowTitle(i18n("Create New Profile"));
+        } else {
+            setWindowTitle(i18n("Edit Profile \"%1\"", profile->name()));
+        }
     }
 }
 
-void EditProfileDialog::setProfile(const Konsole::Profile::Ptr &profile)
+void EditProfileDialog::setProfile(const Konsole::Profile::Ptr &profile, EditProfileDialog::InitialProfileState state)
 {
     Q_ASSERT(profile);
 
     _profile = profile;
 
     // update caption
-    updateCaption(profile);
+    updateCaption(profile, state);
 
     // mark each page of the dialog as out of date
     // and force an update of the currently visible page
@@ -422,6 +420,10 @@ void Konsole::EditProfileDialog::selectProfileName()
 
 void EditProfileDialog::setupGeneralPage(const Profile::Ptr &profile)
 {
+    _generalUi->generalPageMessageWidget->setVisible(false);
+    _generalUi->generalPageMessageWidget->setWordWrap(true);
+    _generalUi->generalPageMessageWidget->setCloseButtonVisible(true);
+
     // basic profile options
     {
         ProfileGroup::Ptr group = profile->asGroup();
@@ -790,6 +792,11 @@ void EditProfileDialog::setupAppearancePage(const Profile::Ptr &profile)
     connect(_appearanceUi->dimValue, &QSlider::valueChanged,
             this, &Konsole::EditProfileDialog::setDimValue);
 
+    _appearanceUi->invertSelectionColorsCheckbox->setChecked(profile->property<bool>(Profile::InvertSelectionColors));
+    connect(_appearanceUi->invertSelectionColorsCheckbox, &QCheckBox::toggled, this, [this](bool checked) {
+        updateTempProfileProperty(Profile::InvertSelectionColors, checked);
+    });
+
     _appearanceUi->displayVerticalLine->setChecked(profile->verticalLine());
     connect(_appearanceUi->displayVerticalLine, &QCheckBox::toggled,
             this, &EditProfileDialog::setVerticalLine);
@@ -1117,6 +1124,7 @@ void EditProfileDialog::showFontDialog()
 {
     if (_fontDialog == nullptr) {
         _fontDialog = new FontDialog(this);
+        _fontDialog->setModal(true);
         connect(_fontDialog, &FontDialog::fontChanged, this, [this](const QFont &font) {
             preview(Profile::Font, font);
             updateFontPreview(font);
@@ -1129,13 +1137,12 @@ void EditProfileDialog::showFontDialog()
         });
         connect(_fontDialog, &FontDialog::rejected, this, [this]() {
             unpreview(Profile::Font);
-            const QFont font = _profile->font();
-            updateFontPreview(font);
+            updateFontPreview(_profile->font());
         });
     }
-    const QFont font = _profile->font();
-    _fontDialog->setFont(font);
-    _fontDialog->exec();
+
+    _fontDialog->setFont(_profile->font());
+    _fontDialog->show();
 }
 
 void EditProfileDialog::updateFontPreview(QFont font)
@@ -1487,9 +1494,9 @@ void EditProfileDialog::showKeyBindingEditor(bool isNewTranslator)
         translator = _keyManager->defaultTranslator();
     }
 
-    Q_ASSERT(translator);
-
-    auto editor = new KeyBindingEditor(this);
+    auto *editor = new KeyBindingEditor(this);
+    editor->setAttribute(Qt::WA_DeleteOnClose);
+    editor->setModal(true);
 
     if (translator != nullptr) {
         editor->setup(translator, lookupProfile()->keyBindings(), isNewTranslator);
@@ -1497,11 +1504,10 @@ void EditProfileDialog::showKeyBindingEditor(bool isNewTranslator)
 
     connect(editor, &Konsole::KeyBindingEditor::updateKeyBindingsListRequest,
             this, &Konsole::EditProfileDialog::updateKeyBindingsList);
-
     connect(editor, &Konsole::KeyBindingEditor::updateTempProfileKeyBindingsRequest,
             this, &Konsole::EditProfileDialog::updateTempProfileProperty);
 
-    editor->exec();
+    editor->show();
 }
 
 void EditProfileDialog::newKeyBinding()
@@ -1543,11 +1549,7 @@ void EditProfileDialog::setupButtonGroup(const ButtonGroupOptions &options, cons
         activeButton = options.buttons[0].button;
     }
     activeButton->setChecked(true);
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 15, 0))
     connect(options.group, QOverload<int>::of(&QButtonGroup::idClicked),
-#else
-    connect(options.group, QOverload<int>::of(&QButtonGroup::buttonClicked),
-#endif
             this, [this, options](int value) {
         if (options.preview) {
             preview(options.profileProperty, value);
