@@ -61,6 +61,11 @@ public:
     explicit EditProfileDialog(QWidget *parent = nullptr);
     ~EditProfileDialog() override;
 
+    enum InitialProfileState {
+        ExistingProfile,
+        NewProfile,
+    };
+
     /**
      * Initializes the dialog with the settings for the specified session
      * type.
@@ -69,8 +74,10 @@ public:
      * with the altered settings.
      *
      * @param profile The profile to be edited
+     * @param state Indicates whether @p profile is an already existing profile
+     * or a new one being created
      */
-    void setProfile(const Profile::Ptr &profile);
+    void setProfile(const Profile::Ptr &profile, InitialProfileState state = EditProfileDialog::ExistingProfile);
 
     /**
      * Selects the text in the profile name edit area.
@@ -87,8 +94,6 @@ public Q_SLOTS:
     // reimplemented
     void reject() override;
 
-    void apply();
-
 protected:
     bool eventFilter(QObject *watched, QEvent *event) override;
 
@@ -234,6 +239,8 @@ private:
     void setupAdvancedPage(const Profile::Ptr &profile);
     void setupMousePage(const Profile::Ptr &profile);
 
+    void setMessageGeneralPage(const QString &msg);
+
     int maxSpinBoxWidth(const KPluralHandlingSpinBox *spinBox, const KLocalizedString &suffix);
 
     // Returns the name of the colorScheme used in the current profile
@@ -263,7 +270,7 @@ private:
     void unpreviewAll();
     void enableIfNonEmptySelection(QWidget *widget, QItemSelectionModel *selectionModel);
 
-    void updateCaption(const Profile::Ptr &profile);
+    void updateCaption(const Profile::Ptr &profile, InitialProfileState state = EditProfileDialog::ExistingProfile);
     void updateTransparencyWarning();
 
     void updateFontPreview(QFont font);
@@ -300,7 +307,7 @@ private:
     // - the name matches the name of an already existing profile
     // - the existing profile config file is read-only
     // otherwise returns true.
-    bool isValidProfileName();
+    bool isProfileNameValid();
 
     Ui::EditProfileGeneralPage      *_generalUi;
     Ui::EditProfileTabsPage         *_tabsUi;
@@ -322,6 +329,7 @@ private:
     };
 
     QMap<KPageWidgetItem *, Page> _pages;
+    KPageWidgetItem *_generalPageItem = nullptr;
 
     Profile::Ptr _tempProfile;
     Profile::Ptr _profile;
